@@ -18,7 +18,7 @@ logger = logging.getLogger(__name__)
 class BoardBase(object):
     __metaclass__ = ABCMeta
 
-    PATH_MODEL_NAME = '/etc/aos/model_name.txt'
+    PATH_MODEL_NAME = '/var/aos/model_name.txt'
 
     def __init__(self):
         self._connector = None
