@@ -98,17 +98,7 @@ class BoardVirtual(BoardBase):
                     self.config.offline_cert_filename = 'unit_offline.pem.crt'
                     self.config.offline_csr_filename = 'unit_offline.pem.csr'
 
-        if not self.config.online_key_folder.endswith("/"):
-            self.config.online_key_folder = self.config.online_key_folder + '/'
-
-        if not self.config.online_cert_folder.endswith("/"):
-            self.config.online_cert_folder = self.config.online_cert_folder + '/'
-
-        if not self.config.offline_key_folder.endswith("/"):
-            self.config.offline_key_folder = self.config.offline_key_folder + '/'
-
-        if not self.config.offline_cert_folder.endswith("/"):
-            self.config.offline_cert_folder = self.config.offline_cert_folder + '/'
+        self._set_slashes_to_paths_end()
 
         sm_config_path = os.path.join(self.CONFIGS_FOLDER, self.SERVICE_MANAGER_CONFIG_FILENAME)
         if not self.is_file_exist(sm_config_path):
